@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::SHANTANU;
 
 # PODNAME: Dist::Zilla::PluginBundle::SHANTANU
 
-our $VERSION = '0.24'; # VERSION
+our $VERSION = '0.25'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -19,7 +19,7 @@ use Dist::Zilla 4.3;
 use Dist::Zilla::PluginBundle::Git 2.028;
 
 use Dist::Zilla::Plugin::Git::NextVersion;
-use Dist::Zilla::Plugin::AutoMetaResources;
+use Dist::Zilla::Plugin::AutoMetaResourcesPrefixed;
 
 use Dist::Zilla::Plugin::ContributorsFromGit;
 
@@ -61,7 +61,7 @@ use Dist::Zilla::Plugin::MakeMaker::Awesome;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
 use Dist::Zilla::Plugin::CheckMetaResources;
 use Dist::Zilla::Plugin::CheckPrereqsIndexed;
-use Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes;
+use Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes 0.0.15;
 use Dist::Zilla::Plugin::ChangelogFromGit::Debian;
 use Dist::Zilla::Plugin::Control::Debian;
 use Dist::Zilla::Plugin::CheckChangesHasContent;
@@ -324,7 +324,7 @@ sub configure {
 
         #Automatically put Resources which need not be specified manually
         [
-            AutoMetaResources => {
+            AutoMetaResourcesPrefixed => {
                 'repository.github' => 'user:shantanubhadoria',
                 'bugtracker.github' => 'user:shantanubhadoria',
                 'bugtracker.rt'     => 0,
@@ -492,7 +492,7 @@ __PACKAGE__->meta->make_immutable;
 #
 # This file is part of Dist-Zilla-PluginBundle-SHANTANU
 #
-# This software is copyright (c) 2014 by Shantanu Bhadoria.
+# This software is copyright (c) 2015 by Shantanu Bhadoria.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -508,7 +508,7 @@ Dist::Zilla::PluginBundle::SHANTANU - Dist Zilla Plugin Bundle the way I like to
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
@@ -671,8 +671,8 @@ plugins used like this:
 
    [@SHANTANU]
    :version = 0.32
-   AutoMetaResources.bugtracker.github = user:shantanu
-   AutoMetaResources.bugtracker.rt = 0
+   AutoMetaResourcesPrefixed.bugtracker.github = user:shantanu
+   AutoMetaResourcesPrefixed.bugtracker.rt = 0
 
 =head1 SEE ALSO
 
@@ -699,7 +699,7 @@ L<Dist::Zilla::Plugin::TaskWeaver>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through github at 
-L<https://github.com/shantanubhadoria/dist-zilla-pluginbundle-shantanu/issues>.
+L<https://github.com/shantanubhadoria/perl-dist-zilla-pluginbundle-shantanu/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -707,9 +707,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/shantanubhadoria/dist-zilla-pluginbundle-shantanu>
+L<https://github.com/shantanubhadoria/perl-dist-zilla-pluginbundle-shantanu>
 
-  git clone git://github.com/shantanubhadoria/dist-zilla-pluginbundle-shantanu.git
+  git clone git://github.com/shantanubhadoria/perl-dist-zilla-pluginbundle-shantanu.git
 
 =head1 AUTHOR
 
@@ -737,7 +737,7 @@ Shantanu Bhadoria <shantanu@shantanu-M14xR2.(none)>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Shantanu Bhadoria.
+This software is copyright (c) 2015 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
